package com.zbf.system.service;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zbf.system.domain.TCkOrderdetail;
import com.zbf.system.domain.TCkOrders;
import com.zbf.system.domain.TCkPickingwavegoods;
import com.zbf.system.domain.TOngoodsshelf;

/**
 * 出库任务Service接口
 *
 * @author tony
 * @date 2024-06-22
 */
public interface ITCkPickingwavegoodsService {
    /**
     * 查询出库任务
     *
     * @param id 出库任务主键
     * @return 出库任务
     */
    public TCkPickingwavegoods selectTCkPickingwavegoodsById(String id);

    /**
     * 查询出库任务列表
     *
     * @param tCkPickingwavegoods 出库任务
     * @return 出库任务集合
     */
    public List<TCkPickingwavegoods> selectTCkPickingwavegoodsList(TCkPickingwavegoods tCkPickingwavegoods);

    /**
     * 新增出库任务
     *
     * @param tCkPickingwavegoods 出库任务
     * @return 结果
     */
    public int insertTCkPickingwavegoods(TCkPickingwavegoods tCkPickingwavegoods);

    /**
     * 修改出库任务
     *
     * @param tCkPickingwavegoods 出库任务
     * @return 结果
     */
    public int updateTCkPickingwavegoods(TCkPickingwavegoods tCkPickingwavegoods);

    /**
     * 批量删除出库任务
     *
     * @param ids 需要删除的出库任务主键集合
     * @return 结果
     */
    public int deleteTCkPickingwavegoodsByIds(String[] ids);

    /**
     * 删除出库任务信息
     *
     * @param id 出库任务主键
     * @return 结果
     */
    public int deleteTCkPickingwavegoodsById(String id);

    /**
     * 批量禁用出库任务
     *
     * @param ids 需要禁用的出库任务主键集合
     * @return 结果
     */
    public int disabledTCkPickingwavegoodsByIds(String[] ids);

    /**
     * 批量启用出库任务
     *
     * @param ids 需要启用的出库任务主键集合
     * @return 结果
     */
    public int enableTCkPickingwavegoodsByIds(String[] ids);

    /**
     * 改变状态
     *
     * @param tCkPickingwavegoods
     * @return 结果
     */
    public int updateStatus(TCkPickingwavegoods tCkPickingwavegoods);

    List<Map<String, Object>> selectMaps(QueryWrapper<TCkPickingwavegoods> queryWrapper);

    Map<String, Object> createTaskData(String s, List<Integer> list);

    List<TCkPickingwavegoods> list(LambdaQueryWrapper<TCkPickingwavegoods> tCkPickingwavegoodsLambdaQueryWrapper);


    int confirm(List<TCkPickingwavegoods> goodsList);

    List<TCkPickingwavegoods> selectJxList(TCkPickingwavegoods tCkPickingwavegoods);
    int updateStatusByPickingids(List<String> ids, TCkPickingwavegoods tCkPickingwavegoods);
    int insertTCkPickingwavegoodsList(List<TCkOrderdetail> tCkOrderdetailList);

    // Map<String, Integer> home(TCkPickingwavegoods pickingwavegoods,
    //                          TOngoodsshelf tOngoodsshelf);

    Integer homePickingwavegoodsCount(TCkPickingwavegoods pickingwavegoods);
    Integer homeTCkOrdersCount(TCkOrders orders);
    Integer homeOngoodsshelfCount(TOngoodsshelf tOngoodsshelf);


}

